/*
 * share/segment.h
 *
 * Copyright 2003, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef share_segment_h
#define share_segment_h


#include<share/config.h>


#define	KERNEL_CODE_DES 0x8					/* ͥ륳ɥǥץ͡ */
#define	KERNEL_DATA_DES 0x10				/* ͥǡǥץ͡ */
#define	USER_CODE_DES   0x1b				/* 桼ɥǥץ͡ */
#define	USER_DATA_DES   0x23				/* 桼ǡǥץ͡ */
#define REAL_CODE_DES   0x28				/* ¥ɥ쥹⡼ѥǥץ͡ */
#define REAL_DATA_DES   0x30				/* ¥ɥ쥹⡼ѥǥץ͡ */
#define APM_CODE_DES    0x38				/* APM BIOSɥǥץ͡ */
#define APM_CODE16_DES  0x40				/* APM BIOS 16bitɥǥץ͡ */
#define APM_DATA_DES    0x48				/* APM BIOSǡǥץ͡ */
#define	TSS_DES         0x50				/* TSSǥץ͡ */
#define GATE_DES        (TSS_DES+MAX_CPU*8)	/* value of Call gate discriptor. */

/* ƥॳ륲ȥ */
#define SYSCALL0_SEG GATE_DES
#define SYSCALL1_SEG GATE_DES+8
#define SYSCALL2_SEG GATE_DES+16
#define SYSCALL3_SEG GATE_DES+24
#define SYSCALL4_SEG GATE_DES+32
#define SYSCALL5_SEG GATE_DES+40
#define SYSCALL6_SEG GATE_DES+48


#endif
